Fast version of the tidy function from the broom package that uses the normal approximation for confidence intervals.

ftidy(model, exp = TRUE, drop_intercept = FALSE)

Arguments

model

Regression model.

exp

Option to exponentiate coefficients.

drop_intercept

Option to drop intercept term from the output table.

Value

Regression model table with confidence intervals.

Examples

if (FALSE) { # \dontrun{
ftidy(mod)
} # }