Sets the file path for whether or not the user is using R on the desktop or on the server.

get_path(x, server_path = "conf")

Arguments

x

Input file path.

server_path

Start of the server path.

Value

File path after desktop or server detection.

Examples

if (FALSE) { # \dontrun{
get_path("//stats/my_folder")
} # }