Run a multivariable `glm()` for a vector of predictor variables with tidy df output

glm_multivar(
  data,
  respvar,
  predvars,
  family = "poisson",
  exp = TRUE,
  additional_term = "",
  fast = TRUE
)

Arguments

data

Input dataset

respvar

Single character string of response variable

predvars

Vector of character strings of predictor variables

family

Single character string of family function

exp

Option to exponentiate model estimates (default is TRUE)

additional_term

Option to add additional terms to model (default is blank)

fast

Option to use normal approximation for confidence intervals (default is TRUE)

Value

Regression model table with confidence intervals

Examples

if (FALSE) { # \dontrun{
glm_multivar(dat, "var", c("var1", "var2"), additional_term="+ offset(log(py))")
} # }