Run a univariable `glm()` for a vector of predictor variables with tidy df output
glm_univar(
data,
respvar,
predvars,
family = "poisson",
exp = TRUE,
additional_term = "",
fast = TRUE
)Input dataset
Single character string of response variable
Vector of character strings of predictor variables
Single character string of family function
Option to exponentiate model estimates (default is TRUE)
Option to add additional terms to model (default is blank)
Option to use normal approximation for confidence intervals (default is TRUE)
Regression model table with confidence intervals
if (FALSE) { # \dontrun{
glm_univar(dat, "var", c("var1", "var2"), additional_term="+ offset(log(py))")
} # }