List of NHS board names in Scotland. Helps to turn a healthboard variable into a factor to ensure all boards are listed in output tables, including those with zero counts.

hb_list(scot = FALSE)

Arguments

scot

Boolean. Include Scotland in the list.

Value

Character vector of NHS boards in Scotland.

Examples

if (FALSE) { # \dontrun{
hb_list()
} # }