Fast version of the tidy function from the broom package that uses the normal approximation for confidence intervals.
ftidy(model, exp = TRUE, drop_intercept = FALSE)Regression model table with confidence intervals.
if (FALSE) { # \dontrun{
ftidy(mod)
} # }