R/get_path.R
get_path.Rd
Sets the file path for whether or not the user is using R on the desktop or on the server.
get_path(x, server_path = "conf")
Input file path.
Start of the server path.
File path after desktop or server detection.
if (FALSE) { # \dontrun{ get_path("//stats/my_folder") } # }